@@ -6,7 +6,8 @@ logger = logging.getLogger(__name__)
 
 
 def reinit_airflow_sql_conn():
-    from airflow.settings import configure_vars, configure_orm
+    from airflow.settings import configure_orm, configure_vars
+
     from dbnd._core.configuration.dbnd_config import config as dbnd_config
 
     configure_vars()
@@ -15,8 +16,9 @@ def reinit_airflow_sql_conn():
     # add query handler before every execute
     # this will print query, code line and stack trace
     if dbnd_config.getboolean("log", "sqlalchemy_trace"):
-        from sqlalchemy import event
         from airflow import settings as airflow_settings
+        from sqlalchemy import event
+
         from dbnd_airflow.db_utils import trace_sqlalchemy_query
 
         event.listen(
@@ -24,11 +26,12 @@ def reinit_airflow_sql_conn():
         )
 
     # this will print query execution time
-    from sqlalchemy import event
     from airflow import settings as airflow_settings
+    from sqlalchemy import event
+
     from dbnd_airflow.db_utils import (
-        profile_before_cursor_execute,
         profile_after_cursor_execute,
+        profile_before_cursor_execute,
     )
 
     event.listen(
